@@ -18,17 +18,17 @@ import polars
 from packaging.version import Version
 
 from gort import config
+from gort.devices.core import GortDevice, GortDeviceSet
 from gort.enums import GuiderStatus
 from gort.exceptions import ErrorCode, GortError, GortGuiderError
-from gort.gort import GortDevice, GortDeviceSet
 from gort.tools import GuiderMonitor, cancel_task
 
 
 if TYPE_CHECKING:
     from clu import AMQPReply
 
-    from gort.core import ActorReply
-    from gort.gort import GortClient
+    from gort.gort import Gort
+    from gort.remote import ActorReply
 
 
 __all__ = ["Guider", "GuiderSet"]
@@ -37,7 +37,7 @@ __all__ = ["Guider", "GuiderSet"]
 class Guider(GortDevice):
     """Class representing a guider."""
 
-    def __init__(self, gort: GortClient, name: str, actor: str, **kwargs):
+    def __init__(self, gort: Gort, name: str, actor: str, **kwargs):
         super().__init__(gort, name, actor)
 
         self.separation: float | None = None
@@ -58,6 +58,13 @@ class Guider(GortDevice):
 
         return self.gort.telescopes[self.name]
 
+    async def update_status(self):
+        """Returns the guider status."""
+
+        status_reply = await self.actor.commands.status()
+
+        return status_reply.flatten()
+
     async def _status_cb(self, reply: AMQPReply):
         """Listens to guider keywords and updates the internal state."""
 
@@ -177,6 +184,8 @@ class Guider(GortDevice):
             await self.actor.commands.adjust_focus(reply_callback=reply_callback)
             return
 
+        await self.update_status()
+
         if self.status & GuiderStatus.NON_IDLE:
             self.write_to_log(
                 "Guider is not idle. Stopping it before focusing.",
@@ -279,6 +288,8 @@ class Guider(GortDevice):
 
         self.separation = None
 
+        await self.update_status()
+
         if self.status & GuiderStatus.NON_IDLE:
             raise GortGuiderError(
                 "Guider is not IDLE",
