@@ -17,7 +17,7 @@ from dataclasses import dataclass
 from functools import partial, wraps
 from time import time
 
-from typing import TYPE_CHECKING, Any, Callable, TypedDict
+from typing import TYPE_CHECKING, Any, Callable, Coroutine, TypedDict
 
 from astropy.time import Time
 
@@ -35,6 +35,7 @@ from gort.tile import Coordinates, Tile
 from gort.tools import (
     GuiderMonitor,
     cancel_task,
+    decap,
     handle_signals,
     insert_to_database,
     register_observation,
@@ -463,7 +464,7 @@ class GortObserver:
 
         except GortObserverCancelledError:
             write_log("Observation cancelled.", "warning")
-            failed = True
+            failed = len(exposures) == 0
 
         except KeyboardInterrupt:
             write_log("Observation interrupted by user.", "warning")
@@ -477,11 +478,15 @@ class GortObserver:
 
     @handle_signals(interrupt_signals, interrupt_helper.run_callback)
     @register_stage_status
-    async def slew(self):
+    async def slew(self, telescopes: list[str] = ["sci", "skye", "skyw", "spec"]):
         """Slew to the telescope fields."""
 
         cotasks = []
 
+        sci: tuple[float, float, float] | None = None
+        spec: tuple[float, float] | None = None
+        sky: dict[str, tuple[float, float]] = {}
+
         with self.register_overhead("slew:stop-guiders"):
             # Stops guiders.
             await self.gort.guiders.stop()
@@ -489,34 +494,36 @@ class GortObserver:
         # Slew telescopes.
         self.write_to_log(f"Slewing to tile_id={self.tile.tile_id}.", level="info")
 
-        sci = (
-            self.tile.sci_coords.ra,
-            self.tile.sci_coords.dec,
-            self.tile.sci_coords.pa,
-        )
-        self.write_to_log(f"Science: {str(self.tile.sci_coords)}")
-
-        spec = None
-        if self.tile.spec_coords and len(self.tile.spec_coords) > 0:
-            first_spec = self.tile.spec_coords[0]
-
-            # For spec we slew to the fibre with which we'll observe first.
-            # This should save a bit of time converging.
-            spec = fibre_slew_coordinates(
-                first_spec.ra,
-                first_spec.dec,
-                self.mask_positions[0],
-                derotated=False,
+        if "sci" in telescopes:
+            sci = (
+                self.tile.sci_coords.ra,
+                self.tile.sci_coords.dec,
+                self.tile.sci_coords.pa,
             )
+            self.write_to_log(f"Science: {str(self.tile.sci_coords)}")
 
-            self.write_to_log(f"Spec: {first_spec} on {self.mask_positions[0]}")
+        if "spec" in telescopes:
+            if self.tile.spec_coords and len(self.tile.spec_coords) > 0:
+                first_spec = self.tile.spec_coords[0]
+
+                # For spec we slew to the fibre with which we'll observe first.
+                # This should save a bit of time converging.
+                spec = fibre_slew_coordinates(
+                    first_spec.ra,
+                    first_spec.dec,
+                    self.mask_positions[0],
+                    derotated=False,
+                )
+
+                self.write_to_log(f"Spec: {first_spec} on {self.mask_positions[0]}")
 
         sky = {}
         for skytel in ["SkyE", "SkyW"]:
-            if skytel.lower() in self.tile.sky_coords:
-                sky_coords_tel = self.tile.sky_coords[skytel.lower()]
+            skytel_l = skytel.lower()
+            if skytel_l in self.tile.sky_coords and skytel_l in telescopes:
+                sky_coords_tel = self.tile.sky_coords[skytel_l]
                 if sky_coords_tel is not None:
-                    sky[skytel.lower()] = (sky_coords_tel.ra, sky_coords_tel.dec)
+                    sky[skytel_l] = (sky_coords_tel.ra, sky_coords_tel.dec)
                     self.write_to_log(f"{skytel}: {sky_coords_tel}")
 
         # For sci we want to slew the k-mirror so that we can apply small positive
@@ -698,6 +705,7 @@ class GortObserver:
         keep_guiding: bool = True,
         object: str | None = None,
         dither_position: int | None = None,
+        exposure_starts_callback: Callable[[Any], Coroutine] | None = None,
     ):
         """Starts exposing the spectrographs.
 
@@ -722,6 +730,8 @@ class GortObserver:
         dither_position
             The dither position. If :obj:`None`, uses the first dither position
             in the tile. Only relevant for exposure registration.
+        exposure_starts_callback
+            A callback to be called when the exposure starts.
 
         Returns
         -------
@@ -774,6 +784,9 @@ class GortObserver:
             exposure.hooks["pre-readout"].append(self._pre_readout)
             exposure.hooks["post-readout"].append(self._post_readout)
 
+            if exposure_starts_callback:
+                exposure.hooks["exposure-starts"].append(exposure_starts_callback)
+
             with self.register_overhead(f"expose:integration-{nexp}"):
                 await exposure.expose(
                     exposure_time=exposure_time,
@@ -850,7 +863,10 @@ class GortObserver:
             table_name = self.gort.config["services.database.tables.overheads"]
             insert_to_database(table_name, payload)
         except Exception as err:
-            self.write_to_log(f"Failed saving overheads to database: {err}", "error")
+            self.write_to_log(
+                f"Failed saving overheads to database: {decap(err)}",
+                "error",
+            )
 
     async def register_exposure(
         self,
@@ -879,7 +895,7 @@ class GortObserver:
         self.write_to_log("Registering observation.", "info")
         registration_payload = {
             "dither": dither_position,
-            "jd": exposure.start_time.jd,
+            "jd": float(exposure.start_time.jd),
             "seeing": -999.0,
             "standards": standards,
             "skies": skies,
@@ -895,7 +911,7 @@ class GortObserver:
         try:
             await register_observation(registration_payload)
         except Exception as err:
-            self.write_to_log(f"Failed registering exposure: {err}", "error")
+            self.write_to_log(f"Failed registering exposure: {decap(err)}", "error")
         else:
             self.write_to_log("Registration complete.")
 
@@ -1249,7 +1265,8 @@ class Standards:
 
             self.observer.write_to_log(
                 f"Standard #{self.current_standard} on "
-                f"{new_mask_position!r} has been acquired."
+                f"{new_mask_position!r} has been acquired.",
+                "info",
             )
 
             # Move mask to uncover fibre.
